(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    250329,       5078]*)
(*NotebookOutlinePosition[    251020,       5102]*)
(*  CellTagsIndexPosition[    250976,       5098]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["applybasis", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["applybasis[", "MR"],
  StyleBox["bz", "IT"],
  StyleBox[", ", "MR"],
  StyleBox["fn", "IT"],
  StyleBox["]", "MR"],
  " applies function ",
  StyleBox["fn", "IT"],
  " to each basis state in the basis ",
  StyleBox["bz", "IT"],
  "."
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["mergebasis",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["dropemptysubspaces",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["transformbasis",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["transformtoPH",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg and declare ",
  StyleBox["c", "IT"],
  " to be a Fermionic operator."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(snegfermionoperators[c]\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell["Test basic functionality", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(applybasis[{{{a}, {a1, a2}}, {{b}, {b1, b2}}}, f]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({{{a}, {f[a1], f[a2]}}, {{b}, {f[b1], f[b2]}}}\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
Apply electron number operator to a basis in the occupation number \
representation and to a basis in the creation operator representation\
\>", \
"ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bvc = qszbasisvc[{c[1], c[2]}];\)\), "\[IndentingNewLine]", 
    \(MatrixForm[bvc]\), "\[IndentingNewLine]", 
    \(H = number[c[1]] + number[c[2]]\), "\[IndentingNewLine]", 
    \(MatrixForm\ @\ applybasis[bvc, H\[CenterDot]# &]\)}], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({\(-1\), \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({\(-1\), 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({0, \(-1\)}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({1, \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({1, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({2, 0}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[5]//MatrixForm="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[6]="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), \({0}\)},
            {\({\(-1\), \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({\(-1\), 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({0, \(-1\)}\), 
              RowBox[{"{", 
                RowBox[{"2", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"2", 
                    TagBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)], 
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[RightAngleBracket]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)]}],
                      DisplayForm]}], ",", 
                  RowBox[{"2", 
                    TagBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)], 
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[RightAngleBracket]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)]}],
                      DisplayForm]}], ",", 
                  RowBox[{"2", 
                    TagBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)], 
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[RightAngleBracket]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)]}],
                      DisplayForm]}], ",", 
                  RowBox[{"2", 
                    TagBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)], 
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[RightAngleBracket]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)]}],
                      DisplayForm]}]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                RowBox[{"2", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({1, \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"3", 
                    TagBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)], 
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[RightAngleBracket]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)]}],
                      DisplayForm]}], ",", 
                  RowBox[{"3", 
                    TagBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)], 
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[RightAngleBracket]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)]}],
                      DisplayForm]}]}], "}"}]},
            {\({1, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"3", 
                    TagBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)], 
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[RightAngleBracket]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)]}],
                      DisplayForm]}], ",", 
                  RowBox[{"3", 
                    TagBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)], 
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[FilledRectangle]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[EmptyRectangle]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                        
                        TagBox[
                          StyleBox["\<\"\[RightAngleBracket]\"\>",
                            FontColor->RGBColor[0, 0.392187, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.39219300000000001, 0.0]]&)]}],
                      DisplayForm]}]}], "}"}]},
            {\({2, 0}\), 
              RowBox[{"{", 
                RowBox[{"4", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[7]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bop = qszbasis[{c[1], c[2]}];\)\), "\[IndentingNewLine]", 
    \(MatrixForm[bvc]\), "\[IndentingNewLine]", 
    \(MatrixForm\ @\ applybasis[bop, H\[CenterDot]# &]\)}], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({\(-1\), \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({\(-1\), 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({0, \(-1\)}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({1, \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({1, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({2, 0}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[9]//MatrixForm="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({\(-1\), \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "+", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], "+", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "+", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "+", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({\(-1\), 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "+", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "+", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({0, \(-1\)}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"2", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], "-", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{\(-2\), 
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}]}], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{
                    RowBox[{"2", 
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}]}], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{
                    RowBox[{"2", 
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}]}], "+", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "+", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{
                    RowBox[{\(-2\), 
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}]}], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"2", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "-", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({1, \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{\(-3\), 
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}]}], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{
                    RowBox[{\(-3\), 
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}]}], "-", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({1, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{\(-3\), 
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}]}], "+", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{
                    RowBox[{\(-3\), 
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}]}], "+", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({2, 0}\), 
              RowBox[{"{", 
                RowBox[{"4", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[10]//MatrixForm="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{704, 748},
WindowMargins->{{Automatic, 161}, {174, Automatic}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 32, 0, 38, "ObjectName"],
Cell[1811, 55, 301, 12, 32, "Usage"],
Cell[2115, 69, 342, 14, 24, "Notes"],

Cell[CellGroupData[{
Cell[2482, 87, 42, 0, 38, "ExampleSection"],
Cell[2527, 89, 118, 4, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[2670, 97, 134, 3, 42, "Input"],
Cell[2807, 102, 103, 2, 21, "Print"]
}, Open  ]],
Cell[2925, 107, 47, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[2997, 111, 106, 2, 26, "Input"],
Cell[3106, 115, 104, 2, 25, "Output"]
}, Open  ]],
Cell[3225, 120, 171, 4, 50, "ExampleText"],

Cell[CellGroupData[{
Cell[3421, 128, 290, 5, 74, "Input"],
Cell[3714, 135, 26745, 526, 210, "Output"],
Cell[30462, 663, 6187, 168, 33, "Output"],
Cell[36652, 833, 27033, 538, 210, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63722, 1376, 223, 4, 58, "Input"],
Cell[63948, 1382, 26745, 526, 210, "Output"],
Cell[90696, 1910, 159593, 3163, 258, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

