(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     35839,       1129]*)
(*NotebookOutlinePosition[     36508,       1152]*)
(*  CellTagsIndexPosition[     36464,       1148]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["grassmanQ", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] grassman",
  StyleBox["Q[", "MR"],
  StyleBox["z", "TI"],
  StyleBox["]", "MR"],
  " returns True if ",
  StyleBox["z", "TI"],
  " is a Grassman constant or variable."
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] Quantities are usually declared to be Grassman \
numbers using ",
  ButtonBox["sneggrassmanconstants",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell["\<\
\[FilledSmallSquare] Grassman numbers anticommute with each other. \
By convention, they also anticommute with Fermionic operators.\
\>", "Text"],

Cell[TextData[{
  "\[FilledSmallSquare] Hermitian conjugation of Grassman numbers is \
interpreted as interchanging ",
  StyleBox["z", "TI"],
  " and ",
  StyleBox["conj[", "MR"],
  StyleBox["z", "TI"],
  StyleBox["]", "MR"],
  "."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] Grassman numbers are automatically moved \
(anticommuted) to the begining of a ",
  ButtonBox["nc",
    ButtonStyle->"AddOnsLink"],
  " sequence."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also ",
  ButtonBox["operatorQ",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["sneggrassmanconstants",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["nc",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["conj",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg and declare ",
  StyleBox["z", "TI"],
  ", ",
  StyleBox["z1", "TI"],
  " and ",
  StyleBox["z2", "TI"],
  " to be Grassman quantities"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(sneggrassmanconstants[z, z1, z2]\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell["Basic operations", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(conj[z]\), "\[IndentingNewLine]", 
    \(conj[conj[z]]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(z\&_\)], "Output",
  CellLabel->"Out[3]="],

Cell[BoxData[
    \(z\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nc[z, z] \[Equal] 0\), "\[IndentingNewLine]", 
    \(nc[conj[z], conj[z]] \[Equal] 0\), "\[IndentingNewLine]", 
    \(nc[z, conj[z]]\), "\[IndentingNewLine]", 
    \(nc[conj[z], z]\), "\[IndentingNewLine]", 
    \(conj[%]\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[5]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[6]="],

Cell[BoxData[
    RowBox[{"z", 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\)}]], "Output",
  CellLabel->"Out[7]="],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{"z", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\)}]}]], "Output",
  CellLabel->"Out[8]="],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{"z", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\)}]}]], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(antikomutator[z1, z2] \[Equal] 0\), "\[IndentingNewLine]", 
    \(komutator[z1, z2]\), "\[IndentingNewLine]", 
    \(conj[nc[z1, z2]]\)}], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[10]="],

Cell[BoxData[
    RowBox[{"2", 
      RowBox[{"z1", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "z2"}]}]], "Output",
  CellLabel->"Out[11]="],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{\(z1\&_\), 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], \(z2\&_\)}]}]], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["Anticommutation with Fermionic operators", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(snegfermionoperators[c];\)\), "\[IndentingNewLine]", 
    \(nc[c[CR], z]\), "\[IndentingNewLine]", 
    \(nc[c[CR], z, z1]\), "\[IndentingNewLine]", 
    \(nc[c[CR], z, z1, z2]\), "\[IndentingNewLine]", 
    \(nc[z1, c[CR], z2]\), "\[IndentingNewLine]", 
    \(conj[%]\)}], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{"z", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[14]="],

Cell[BoxData[
    RowBox[{"z", 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], "z1", 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          InterpretationBox[\(c\^"\[Dagger]"\),
            Superscript[ c, "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output",
  CellLabel->"Out[15]="],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{"z", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "z1", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "z2", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[16]="],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{"z1", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "z2", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[17]="],

Cell[BoxData[
    RowBox[{\(z1\&_\), 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], \(z2\&_\), 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          InterpretationBox[\(c\^\*"\<\"\"\>"\),
            Superscript[ c, ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["Fermionic coherent state \[LeftBracketingBar]z\[RightAngleBracket]", \
"ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(a = Exp[\(-nc[conj[z], z]\)/2]\), "\[IndentingNewLine]", 
    \(snegSeries[a]\), "\[IndentingNewLine]", 
    \(b = Exp[nc[c[CR], z]]\), "\[IndentingNewLine]", 
    \(snegSeries[b]\), "\[IndentingNewLine]", 
    \(nc[a, b, VACUUM]\), "\[IndentingNewLine]", 
    \(% == coh[z, c[]]\)}], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    SuperscriptBox["\[ExponentialE]", 
      RowBox[{\(1\/2\), 
        RowBox[{"z", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\)}]}]]], "Output",
  CellLabel->"Out[19]="],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{\(1\/2\), 
        RowBox[{"z", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\)}]}]}]], "Output",
  CellLabel->"Out[20]="],

Cell[BoxData[
    SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\<\"-\"\>", 
        RowBox[{"z", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[\(c\^"\[Dagger]"\),
                Superscript[ c, "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}]]], "Output",
  CellLabel->"Out[21]="],

Cell[BoxData[
    RowBox[{"1", "-", 
      RowBox[{"z", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[22]="],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
          FontColor->RGBColor[1, 0, 1]],
        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], "-", 
      RowBox[{"z", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}], "+", 
      RowBox[{\(1\/2\), 
        RowBox[{"z", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\), 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            
            StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
              FontColor->RGBColor[1, 0, 1]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}]}]}]], "Output",\

  CellLabel->"Out[23]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["Conjugated coherent state \[LeftAngleBracket]z\[RightBracketingBar]", \
"ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ca = Exp[\(-nc[conj[z], z]\)/2]\), "\[IndentingNewLine]", 
    \(cb = Exp[nc[conj[z], c[AN]]]\), "\n", 
    \(nc[conj\ @\ VACUUM, cb, ca]\ \), "\[IndentingNewLine]", 
    \(% == conj[coh[z, c[]]]\)}], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    SuperscriptBox["\[ExponentialE]", 
      RowBox[{\(1\/2\), 
        RowBox[{"z", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\)}]}]]], "Output",
  CellLabel->"Out[25]="],

Cell[BoxData[
    SuperscriptBox["\[ExponentialE]", 
      RowBox[{\(z\&_\), 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^\*"\<\"\"\>"\),
              Superscript[ c, ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]]], "Output",
  CellLabel->"Out[26]="],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
          FontColor->RGBColor[1, 0, 1]],
        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], "+", 
      RowBox[{\(1\/2\), 
        RowBox[{"z", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\), 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            
            StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
              FontColor->RGBColor[1, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}]}], "+", 
      RowBox[{\(z\&_\), 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^\*"\<\"\"\>"\),
              Superscript[ c, ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[27]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["coh[0]", "MR"],
  " is vacuum (i.e. ",
  StyleBox["coh[0]", "MR"],
  " is annihilated by the annihilation operator ",
  StyleBox["c", "TI"],
  "). Furthermore, ",
  StyleBox["coh[", "MR"],
  StyleBox["z", "TI"],
  StyleBox["]", "MR"],
  " is eigenstate of the annihilation operator with eigenvalue ",
  StyleBox["z", "TI"],
  "."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nc[c[AN], coh[0, c[]]] \[Equal] 0\), "\[IndentingNewLine]", 
    \(nc[c[AN], coh[z, c[]]] \[Equal] nc[z, VACUUM]\)}], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[29]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["Coherent states are normalized to 1", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[conj@coh[z, c[]], coh[z, c[]]] \[Equal] 1\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["Overlap of two coherent states: overcomplete basis", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(nc[conj\ @\ coh[z1, c[]], coh[z2, c[]]] // 
      Expand\)\(\[IndentingNewLine]\)
    \)\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{\(1\/2\), 
        RowBox[{"z1", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z1\&_\)}]}], "-", 
      RowBox[{"z2", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], \(z1\&_\)}], "+", 
      RowBox[{\(1\/2\), 
        RowBox[{"z2", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z2\&_\)}]}], "-", 
      RowBox[{\(1\/4\), 
        RowBox[{"z1", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], "z2", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z1\&_\), 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z2\&_\)}]}]}]], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["Proof of an identity", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nul = nc[VACUUM]\), "\[IndentingNewLine]", 
    \(one = nc[c[CR], VACUUM]\), "\[IndentingNewLine]", 
    \(phi[z_] = coh[z, c[]]\), "\[IndentingNewLine]", 
    \(\(\((nc[nc[conj[#], phi[z]], 
              nc[conj[phi[z]], #]] == \[IndentingNewLine]nc[
              nc[conj[phi[\(-z\)]], #], 
              nc[conj[#], phi[z]]])\) &\)\  /@ {nul, one}\)}], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    TagBox[
      StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\[RightAngleBracket]\
\"\>",
        FontColor->RGBColor[1, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]], "Output",
  CellLabel->"Out[33]="],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          InterpretationBox[\(c\^"\[Dagger]"\),
            Superscript[ c, "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
          FontColor->RGBColor[1, 0, 1]],
        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}]], "Output",
  CellLabel->"Out[34]="],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
          FontColor->RGBColor[1, 0, 1]],
        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], "-", 
      RowBox[{"z", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}], "+", 
      RowBox[{\(1\/2\), 
        RowBox[{"z", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\), 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            
            StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
              FontColor->RGBColor[1, 0, 1]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}]}]}]], "Output",\

  CellLabel->"Out[35]="],

Cell[BoxData[
    \({True, True}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell["Projection operator", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nc[coh[z, c[]], conj\ @\ coh[z, c[]]]\), "\[IndentingNewLine]", 
    \(proj = nc[int[conj[z], z], %]\)}], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}], "+", 
      RowBox[{\(1\/2\), 
        RowBox[{
          TagBox[
            
            StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
              FontColor->RGBColor[1, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], "z", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\), 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            
            StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
              FontColor->RGBColor[1, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}]}], "+", 
      RowBox[{
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\), 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^\*"\<\"\"\>"\),
              Superscript[ c, ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{"z", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}], "+", 
      RowBox[{\(1\/2\), 
        RowBox[{"z", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\), 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            
            StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
              FontColor->RGBColor[1, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            
            StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
              FontColor->RGBColor[1, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}]}], "-", 
      RowBox[{"z", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\), 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^\*"\<\"\"\>"\),
              Superscript[ c, ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[37]="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^\*"\<\"\"\>"\),
              Superscript[ c, ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell["Trace(op)", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nc[conj@coh[z, c[]], op, coh[z, c[]]]\), "\[IndentingNewLine]", 
    \(trop = nc[int[conj[z], z], %]\), "\[IndentingNewLine]", 
    \(trop /. op \[Rule] nc[c[CR], c[AN]]\)}], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "op", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}], "+", 
      RowBox[{\(1\/2\), 
        RowBox[{"z", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\), 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            
            StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
              FontColor->RGBColor[1, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], "op", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            
            StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
              FontColor->RGBColor[1, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}]}], "-", 
      RowBox[{
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "op", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "z", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}], "+", 
      RowBox[{\(1\/2\), 
        RowBox[{
          TagBox[
            
            StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
              FontColor->RGBColor[1, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], "op", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], "z", 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], \(z\&_\), 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            
            StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
              FontColor->RGBColor[1, 0, 1]],
            (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}]}], "+", 
      RowBox[{\(z\&_\), 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^\*"\<\"\"\>"\),
              Superscript[ c, ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "op", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}], "-", 
      RowBox[{\(z\&_\), 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^\*"\<\"\"\>"\),
              Superscript[ c, ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "op", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "z", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}]}]], "Output",
  CellLabel->"Out[39]="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "op", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}], "+", 
      RowBox[{
        TagBox[
          
          StyleBox["\<\"\[LeftAngleBracket]\[Diameter]\
\[RightDoubleBracketingBar]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^\*"\<\"\"\>"\),
              Superscript[ c, ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], "op", 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\^"\[Dagger]"\),
              Superscript[ c, "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          
          StyleBox["\<\"\[LeftDoubleBracketingBar]\[Diameter]\
\[RightAngleBracket]\"\>",
            FontColor->RGBColor[1, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 1]]&)]}]}]], "Output",
  CellLabel->"Out[40]="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 453}, {Automatic, 54}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 31, 0, 38, "ObjectName"],
Cell[1810, 55, 220, 8, 32, "Usage"],
Cell[2033, 65, 193, 6, 40, "Notes"],
Cell[2229, 73, 155, 3, 40, "Text"],
Cell[2387, 78, 244, 9, 40, "Notes"],
Cell[2634, 89, 199, 6, 40, "Notes"],
Cell[2836, 97, 322, 14, 24, "Notes"],

Cell[CellGroupData[{
Cell[3183, 115, 42, 0, 38, "ExampleSection"],
Cell[3228, 117, 183, 8, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3436, 129, 143, 3, 42, "Input"],
Cell[3582, 134, 103, 2, 21, "Print"]
}, Open  ]],
Cell[3700, 139, 39, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3764, 143, 113, 3, 42, "Input"],
Cell[3880, 148, 62, 2, 25, "Output"],
Cell[3945, 152, 59, 2, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4041, 159, 280, 6, 90, "Input"],
Cell[4324, 167, 62, 2, 25, "Output"],
Cell[4389, 171, 62, 2, 25, "Output"],
Cell[4454, 175, 155, 4, 25, "Output"],
Cell[4612, 181, 189, 5, 25, "Output"],
Cell[4804, 188, 189, 5, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5030, 198, 193, 4, 58, "Input"],
Cell[5226, 204, 63, 2, 25, "Output"],
Cell[5292, 208, 179, 5, 25, "Output"],
Cell[5474, 215, 197, 5, 28, "Output"]
}, Open  ]],
Cell[5686, 223, 63, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[5774, 227, 330, 7, 106, "Input"],
Cell[6107, 236, 448, 13, 29, "Output"],
Cell[6558, 251, 482, 14, 29, "Output"],
Cell[7043, 267, 624, 17, 29, "Output"],
Cell[7670, 286, 537, 15, 29, "Output"],
Cell[8210, 303, 485, 14, 28, "Output"]
}, Open  ]],
Cell[8710, 320, 91, 1, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[8826, 325, 339, 7, 106, "Input"],
Cell[9168, 334, 235, 6, 33, "Output"],
Cell[9406, 342, 220, 6, 42, "Output"],
Cell[9629, 350, 512, 14, 31, "Output"],
Cell[10144, 366, 445, 13, 29, "Output"],
Cell[10592, 381, 1435, 40, 42, "Output"],
Cell[12030, 423, 63, 2, 25, "Output"]
}, Open  ]],
Cell[12108, 428, 92, 1, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[12225, 433, 255, 5, 74, "Input"],
Cell[12483, 440, 235, 6, 33, "Output"],
Cell[12721, 448, 457, 13, 29, "Output"],
Cell[13181, 463, 1417, 38, 42, "Output"],
Cell[14601, 503, 63, 2, 25, "Output"]
}, Open  ]],
Cell[14679, 508, 376, 13, 50, "ExampleText"],

Cell[CellGroupData[{
Cell[15080, 525, 172, 3, 42, "Input"],
Cell[15255, 530, 63, 2, 25, "Output"],
Cell[15321, 534, 63, 2, 25, "Output"]
}, Open  ]],
Cell[15399, 539, 58, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[15482, 543, 102, 2, 26, "Input"],
Cell[15587, 547, 63, 2, 25, "Output"]
}, Open  ]],
Cell[15665, 552, 73, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[15763, 556, 150, 4, 42, "Input"],
Cell[15916, 562, 840, 21, 42, "Output"]
}, Open  ]],
Cell[16771, 586, 43, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[16839, 590, 411, 8, 106, "Input"],
Cell[17253, 600, 244, 6, 25, "Output"],
Cell[17500, 608, 597, 17, 29, "Output"],
Cell[18100, 627, 1435, 40, 42, "Output"],
Cell[19538, 669, 71, 2, 25, "Output"]
}, Open  ]],
Cell[19624, 674, 42, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[19691, 678, 160, 3, 42, "Input"],
Cell[19854, 683, 5580, 150, 79, "Output"],
Cell[25437, 835, 1850, 52, 29, "Output"]
}, Open  ]],
Cell[27302, 890, 32, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[27359, 894, 229, 4, 58, "Input"],
Cell[27591, 900, 6116, 162, 101, "Output"],
Cell[33710, 1064, 2026, 56, 29, "Output"],
Cell[35739, 1122, 60, 2, 25, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

