(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     31472,        936]*)
(*NotebookOutlinePosition[     32465,        970]*)
(*  CellTagsIndexPosition[     32353,        963]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["normalorder", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["normalorder[", "MR"],
  StyleBox["expr", "TI"],
  StyleBox["]", "MR"],
  " normal orders an expression by subtracting its vacuum expectation value \
(vev).\n\[FilledSmallSquare] n",
  StyleBox["ormalorderwick[expr]", "MR"],
  " normal orders an expression by subtracting its vev. Wick's theorem is \
used to compute the vev."
}], "Usage",
  CellTags->{"normalorder", "normalorderwick"}],

Cell[TextData[{
  "\[FilledSmallSquare] The functions are defined as ",
  StyleBox["normalorder[", "MR"],
  StyleBox["expr_", "TI"],
  StyleBox["]:=", "MR"],
  StyleBox["expr", "TI"],
  StyleBox["-vev[", "MR"],
  StyleBox["expr", "TI"],
  StyleBox["]", "MR"],
  " and ",
  StyleBox["normalorderwick[", "MR"],
  StyleBox["expr_", "TI"],
  StyleBox["]:=", "MR"],
  StyleBox["expr", "TI"],
  StyleBox["-vevwick[", "MR"],
  StyleBox["expr", "TI"],
  StyleBox["]", "MR"],
  "."
}], "Notes"],

Cell["\<\
\[FilledSmallSquare] By definition, the vacuum expectation value of \
a normal ordered expression is zero.\
\>", "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["vev",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["wick",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["dd",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg and declare ",
  StyleBox["c", "TI"],
  " to be a fermionic operator"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c];\)\), "\[IndentingNewLine]", 
    \(\(ordering[c] = SEA;\)\), "\[IndentingNewLine]", 
    \(\(snegfreeindexes[k, k1, k2, k3, 
        k4, \[Sigma]1, \[Sigma]2, \[Sigma]3, \[Sigma]4];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell[TextData[{
  StyleBox["normalorder", "MR"],
  " can be used for simple expressions."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(op = nc[c[CR, k], c[AN, k]]\), "\[IndentingNewLine]", 
    \(normalorder[op]\), "\[IndentingNewLine]", 
    \(vev[%] \[Equal] 0\)}], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          InterpretationBox[\(c\_k\%\("\[Dagger]"\)\),
            Subsuperscript[ c, 
              RowBox[ {k}], "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          InterpretationBox[\(c\_k\%\(\*"\<\"\"\>"\)\),
            Subsuperscript[ c, 
              RowBox[ {k}], ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output",
  CellLabel->"Out[11]="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_k\%\("\[Dagger]"\)\),
              Subsuperscript[ c, 
                RowBox[ {k}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_k\%\(\*"\<\"\"\>"\)\),
              Subsuperscript[ c, 
                RowBox[ {k}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
        DisplayForm]}]], "Output",
  CellLabel->"Out[12]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(op = nc[c[CR, k1], c[AN, k2]]\), "\[IndentingNewLine]", 
    \(normalorder[op]\), "\[IndentingNewLine]", 
    \(vev[%] \[Equal] 0\)}], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          InterpretationBox[\(c\_k1\%\("\[Dagger]"\)\),
            Subsuperscript[ c, 
              RowBox[ {k1}], "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          InterpretationBox[\(c\_k2\%\(\*"\<\"\"\>"\)\),
            Subsuperscript[ c, 
              RowBox[ {k2}], ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output",
  CellLabel->"Out[14]="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_k1\%\("\[Dagger]"\)\),
              Subsuperscript[ c, 
                RowBox[ {k1}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_k2\%\(\*"\<\"\"\>"\)\),
              Subsuperscript[ c, 
                RowBox[ {k2}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[15]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[TextData[{
  "For longer strings of operators, ",
  StyleBox["normalorderwick", "MR"],
  " must be used."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(op = 
      nc[c[CR, k1, UP], c[AN, k2, UP], c[CR, k3, DO], 
        c[AN, k4, DO]]\), "\[IndentingNewLine]", 
    \(normalorderwick[op]\), "\[IndentingNewLine]", 
    \(vevwick[%] \[Equal] 0\)}], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[20]="],

Cell[BoxData[
    RowBox[{
      RowBox[{"\<\"-\"\>", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k3", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k3, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[21]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(op = 
      nc[c[CR, k1, \[Sigma]1], c[AN, k2, \[Sigma]2], c[CR, k3, \[Sigma]3], 
        c[AN, k4, \[Sigma]4]]\), "\[IndentingNewLine]", 
    \(normalorderwick[op]\), "\[IndentingNewLine]", 
    \(vevwick[%] \[Equal] 0\)}], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 
                    0.0]]&)], \(\[Sigma]2  \[Sigma]3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[\(c\_\(k1  \[Sigma]1\)\%\("\[Dagger]"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k1, \[Sigma]1}], "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[\(c\_\(k4  \[Sigma]4\)\%\(\*"\<\"\"\>"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k4, \[Sigma]4}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_\(k1  \[Sigma]1\)\%\("\[Dagger]"\)\),
              Subsuperscript[ c, 
                RowBox[ {k1, \[Sigma]1}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_\(k3  \[Sigma]3\)\%\("\[Dagger]"\)\),
              Subsuperscript[ c, 
                RowBox[ {k3, \[Sigma]3}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_\(k2  \[Sigma]2\)\%\(\*"\<\"\"\>"\)\),
              Subsuperscript[ c, 
                RowBox[ {k2, \[Sigma]2}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_\(k4  \[Sigma]4\)\%\(\*"\<\"\"\>"\)\),
              Subsuperscript[ c, 
                RowBox[ {k4, \[Sigma]4}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[26]="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 
                    0.0]]&)], \(\[Sigma]2  \[Sigma]3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[\(c\_\(k1  \[Sigma]1\)\%\("\[Dagger]"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k1, \[Sigma]1}], "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[\(c\_\(k4  \[Sigma]4\)\%\(\*"\<\"\"\>"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k4, \[Sigma]4}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_\(k1  \[Sigma]1\)\%\("\[Dagger]"\)\),
              Subsuperscript[ c, 
                RowBox[ {k1, \[Sigma]1}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_\(k3  \[Sigma]3\)\%\("\[Dagger]"\)\),
              Subsuperscript[ c, 
                RowBox[ {k3, \[Sigma]3}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_\(k2  \[Sigma]2\)\%\(\*"\<\"\"\>"\)\),
              Subsuperscript[ c, 
                RowBox[ {k2, \[Sigma]2}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(c\_\(k4  \[Sigma]4\)\%\(\*"\<\"\"\>"\)\),
              Subsuperscript[ c, 
                RowBox[ {k4, \[Sigma]4}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 
                    0.0]]&)], \(\[Sigma]1  \[Sigma]4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 
                    0.0]]&)], \(\[Sigma]2  \[Sigma]3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 
                    0.0]]&)], \(\[Sigma]1  \[Sigma]4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 
                    0.0]]&)], \(\[Sigma]2  \[Sigma]3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 
                    0.0]]&)], \(\[Sigma]1  \[Sigma]2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 
                    0.0]]&)], \(\[Sigma]3  \[Sigma]4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[27]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 265}, {143, Automatic}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "normalorder"->{
    Cell[1812, 55, 441, 11, 86, "Usage",
      CellTags->{"normalorder", "normalorderwick"}]},
  "normalorderwick"->{
    Cell[1812, 55, 441, 11, 86, "Usage",
      CellTags->{"normalorder", "normalorderwick"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"normalorder", 32115, 953},
  {"normalorderwick", 32233, 956}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 33, 0, 38, "ObjectName"],
Cell[1812, 55, 441, 11, 86, "Usage",
  CellTags->{"normalorder", "normalorderwick"}],
Cell[2256, 68, 485, 18, 40, "Notes"],
Cell[2744, 88, 131, 3, 24, "Notes"],
Cell[2878, 93, 240, 11, 24, "Notes"],

Cell[CellGroupData[{
Cell[3143, 108, 42, 0, 38, "ExampleSection"],
Cell[3188, 110, 117, 4, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3330, 118, 321, 6, 74, "Input"],
Cell[3654, 126, 103, 2, 21, "Print"]
}, Open  ]],
Cell[3772, 131, 108, 3, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3905, 138, 187, 4, 58, "Input"],
Cell[4095, 144, 715, 22, 33, "Output"],
Cell[4813, 168, 1076, 32, 33, "Output"],
Cell[5892, 202, 63, 2, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5992, 209, 189, 4, 58, "Input"],
Cell[6184, 215, 719, 22, 33, "Output"],
Cell[6906, 239, 1551, 45, 33, "Output"],
Cell[8460, 286, 63, 2, 25, "Output"]
}, Open  ]],
Cell[8538, 291, 129, 4, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[8692, 299, 251, 6, 74, "Input"],
Cell[8946, 307, 3204, 86, 33, "Output"],
Cell[12153, 395, 4945, 131, 33, "Output"],
Cell[17101, 528, 63, 2, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17201, 535, 279, 6, 74, "Input"],
Cell[17483, 543, 3392, 92, 33, "Output"],
Cell[20878, 637, 10488, 290, 96, "Output"],
Cell[31369, 929, 63, 2, 25, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

