(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    402916,      10969]*)
(*NotebookOutlinePosition[    486470,      13799]*)
(*  CellTagsIndexPosition[    486426,      13795]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Testing Wick's theorem\nPart of SNEG package, ",
  ButtonBox["http://nrgljubljana.ijs.si/sneg",
    ButtonData:>"",
    ButtonStyle->"Hyperlink"],
  "\n(C) Rok Zitko, rok.zitko@ijs.si, 2006, 2007"
}], "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(<< sneg`sneg`;\)\)], "Input"],

Cell[BoxData[
    \("sneg 1.167 Copyright (C) 2007 Rok Zitko"\)], "Print"]
}, Open  ]],

Cell["\<\
Note: a number of functions, such as number[], depend on the fact that the \
last index is the spin index. Therefore the channel index must come before \
the spin index!\
\>", "Text"],

Cell[BoxData[{
    \(\(snegfermionoperators[a, c, d];\)\), "\[IndentingNewLine]", 
    \(snegrealconstants[x]\  (*\ Actually, \ 
      this\ is\ a\ coordinate\ *) \)}], "Input"],

Cell[BoxData[
    \(\(Off[General::spell1];\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      It\ is\ important\ not\ to\ have\ interfering\ \(\(indeces\ !!\)!\)\ \
*) \)\(\[IndentingNewLine]\)\(snegfreeindexes[k, k1, k2, k3, k4, 
      kp, \[Sigma], \[Tau], \[Delta]p]\[IndentingNewLine]
    snegfreeindexes[\[Alpha], \[Alpha]1, \[Alpha]2, \[Alpha]3, \[Alpha]4, \
\[Alpha]p]\[IndentingNewLine]
    snegfreeindexes[\[Beta]]\)\)\)], "Input"],

Cell["Note: O=:O:+<O>", "Text"],

Cell["c is SEA ordered, a and d are EMPTY ordered", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ordering[c] = SEA;\)\), "\[IndentingNewLine]", 
    \(ordering[c] === SEA\), "\[IndentingNewLine]", 
    \(ordering[d] === EMPTY\)}], "Input"],

Cell[BoxData[
    \(True\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
Unequal operators: always sort cannonically, creation operators to the left, \
etc.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[c[AN, k, 1, UP], d[CR, k, 1, UP]]\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {k, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output"]
}, Open  ]],

Cell["Equal operators with EMPTY ordering", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[a[AN, 1], a[CR, 1]]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["a", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ a, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["a", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ a, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[c[AN, k, 1, UP], c[CR, k, 1, DO]]\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[c[AN, k, 1, UP], c[CR, k, 1, DO], c[AN, k1, 1, UP], 
      c[CR, k1, 1, UP]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\<\"-\"\>", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output"]
}, Open  ]],

Cell["Empty band: creation operators shifted to the left", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nc[d[AN, k, 1, sp1], d[CR, k, 1, sp2]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(sp1  sp2\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[\(d\_\(k  1  sp2\)\%\("\[Dagger]"\)\),
              Subsuperscript[ d, 
                RowBox[ {k, 1, sp2}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[\(d\_\(k  1  sp1\)\%\(\*"\<\"\"\>"\)\),
              Subsuperscript[ d, 
                RowBox[ {k, 1, sp1}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 3}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 5}],

Cell["\<\
Let's test improved definition of vev[], which knows more about vacuum \
state\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(vev[a[CR, UP]~nc~a[AN, UP]]\), "\[IndentingNewLine]", 
    \(vev[a[AN, 1]~nc~a[CR, 1]]\)}], "Input"],

Cell[BoxData[
    \(0\)], "Output"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(number[c[k, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(vev[%]\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "\[Alpha]", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, \[Alpha], 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "\[Alpha]", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, \[Alpha], 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "\[Alpha]", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, \[Alpha], 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "\[Alpha]", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, \[Alpha], 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output"],

Cell[BoxData[
    RowBox[{"2", " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
        DisplayForm]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(vev[
      c[CR, k, \[Alpha], \[Sigma]]~nc~
        c[AN, k, \[Alpha], \[Sigma]]]\), "\[IndentingNewLine]", 
    \(vev[
      c[AN, k, \[Alpha], \[Sigma]]~nc~
        c[CR, k, \[Alpha], \[Sigma]]]\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[Theta]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
      DisplayForm]], "Output"],

Cell[BoxData[
    RowBox[{"1", "-", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
        DisplayForm]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(vev[
      c[CR, k1, \[Alpha], \[Sigma]]~nc~
        c[AN, k2, \[Alpha], \[Sigma]]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm]}]], "Output"]
}, Open  ]],

Cell["\<\
This one can be shown to be equal to 0: different number of spins!\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nc[c[AN, k, 1, UP], c[CR, k, 1, DO], c[AN, k1, 1, UP], 
      c[CR, k1, 1, UP]]\), "\[IndentingNewLine]", 
    \(vev[%]\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\<\"-\"\>", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nc[c[AN, k, 1, UP], c[CR, k, 1, UP], c[AN, k1, 1, UP], 
      c[CR, k1, 1, UP]]\), "\[IndentingNewLine]", 
    \(vevwick[%]\), "\[IndentingNewLine]", 
    \(SimplifyKD[%]\)}], "Input"],

Cell[BoxData[
    RowBox[{"1", "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output"],

Cell[BoxData[
    RowBox[{"1", "-", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
        DisplayForm], "+", 
      RowBox[{
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm]}], "-", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], "+", 
      RowBox[{
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], " ", 
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[Theta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
              DisplayForm]}], "+", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Theta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], "(", "k", ")"}],
            DisplayForm]}], ")"}], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", "k1", ")"}],
        DisplayForm]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nc[c[CR, k1, 1, UP], c[CR, k2, 1, UP], c[AN, k1, 1, UP], 
      c[AN, k2, 1, UP]]\), "\[IndentingNewLine]", 
    \(vevwick[%]\), "\[IndentingNewLine]", 
    \(SimplifyKD[%]\)}], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          InterpretationBox[
            SubsuperscriptBox["c", 
              RowBox[{"k1", "1", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[ c, 
              RowBox[ {k1, 1, 
                StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
              "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          InterpretationBox[
            SubsuperscriptBox["c", 
              RowBox[{"k2", "1", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[ c, 
              RowBox[ {k2, 1, 
                StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
              "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          InterpretationBox[
            SubsuperscriptBox["c", 
              RowBox[{"k1", "1", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)]}], "\<\"\"\>"],
            Subsuperscript[ c, 
              RowBox[ {k1, 1, 
                StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
              ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          InterpretationBox[
            SubsuperscriptBox["c", 
              RowBox[{"k2", "1", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)]}], "\<\"\"\>"],
            Subsuperscript[ c, 
              RowBox[ {k2, 1, 
                StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
              ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"-", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Theta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k2\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k2\), ")"}],
          DisplayForm]}]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        RowBox[{\(-1\), "+", 
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], ")"}], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k2\), ")"}],
        DisplayForm]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(vevwick[
      nc[c[CR, k1, \[Alpha], \[Sigma]], c[AN, k2, \[Alpha], \[Sigma]], 
        c[CR, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]]]\), "\[IndentingNewLine]", 
    \(SimplifyKD[%]\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}]}]], "Output"],

Cell[BoxData[
    RowBox[{
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], " ", 
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], " ", 
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[Theta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
              DisplayForm]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], " ", 
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], " ", 
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[Theta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], "(", "k3", ")"}],
              DisplayForm]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(normalorder[
      nc[c[AN, k, 1, UP], c[CR, k, 1, UP], c[AN, k1, 1, UP], 
        c[CR, k1, 1, UP]]]\), "\[IndentingNewLine]", 
    \(vev[%]\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\<\"-\"\>", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
        DisplayForm], "-", 
      RowBox[{
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm]}], "+", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], "+", 
      RowBox[{"vev", "[", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], "]"}]}]], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 0.5}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 3}],

Cell["Tests of normal ordering", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nc[c[CR, k1, \[Alpha], \[Sigma]], 
      c[AN, k2, \[Alpha], \[Sigma]]]\), "\[IndentingNewLine]", 
    \(normalorder[
      nc[c[CR, k1, \[Alpha], \[Sigma]], 
        c[AN, k2, \[Alpha], \[Sigma]]]]\)}], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          
          InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
            Subsuperscript[ c, 
              RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          
          InterpretationBox[\(c\_\(k2  \[Alpha]  \[Sigma]\)\%\(\*"\<\"\"\>"\)\
\),
            Subsuperscript[ c, 
              RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
              Subsuperscript[ c, 
                RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k2  \[Alpha]  \[Sigma]\)\%\(\*"\<\"\"\>"\
\)\),
              Subsuperscript[ c, 
                RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}]}]], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 0.5}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 3}],

Cell["Fermion fields in continuous space", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(psi[\[Alpha]_, \[Sigma]_] = 
      sum[Exp[I\ k\ x] c[AN, k, \[Alpha], \[Sigma]], {k}]\)], "Input"],

Cell[BoxData[
    RowBox[{"sum", "[", 
      RowBox[{
        RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\), " ", 
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k, \[Alpha], \[Sigma]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], ",", \({k}\)}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(NumericQ[x]\), "\[IndentingNewLine]", 
    \(NumericQ[k]\), "\[IndentingNewLine]", 
    \(NumericQ[Exp[I\ k\ x]]\), "\[IndentingNewLine]", 
    \(Conjugate[k] ^= k\), "\[IndentingNewLine]", 
    \(conj[Exp[I\ k\ x]]\)}], "Input"],

Cell[BoxData[
    \(True\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"],

Cell[BoxData[
    \(k\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(conj[psi[\[Alpha], \[Sigma]]]\)], "Input"],

Cell[BoxData[
    RowBox[{"sum", "[", 
      RowBox[{
        RowBox[{\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\)\), " ", 
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k  \[Alpha]  \[Sigma]\)\%\("\[Dagger]"\
\)\),
                Subsuperscript[ c, 
                  RowBox[ {k, \[Alpha], \[Sigma]}], "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], ",", \({k}\)}], "]"}]], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 3}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 5}],

Cell[CellGroupData[{

Cell[BoxData[
    \(x1 = 
      nc[c[CR, k1, \[Alpha], \[Sigma]], c[CR, k2, \[Alpha], \[Sigma]], 
        c[AN, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          
          InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
            Subsuperscript[ c, 
              RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          
          InterpretationBox[\(c\_\(k2  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
            Subsuperscript[ c, 
              RowBox[ {k2, \[Alpha], \[Sigma]}], "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          
          InterpretationBox[\(c\_\(k3  \[Alpha]  \[Sigma]\)\%\(\*"\<\"\"\>"\)\
\),
            Subsuperscript[ c, 
              RowBox[ {k3, \[Alpha], \[Sigma]}], ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          
          InterpretationBox[\(c\_\(k4  \[Alpha]  \[Sigma]\)\%\(\*"\<\"\"\>"\)\
\),
            Subsuperscript[ c, 
              RowBox[ {k4, \[Alpha], \[Sigma]}], ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(contractedpairs[1, x4]\), "\[IndentingNewLine]", 
    \(contractedpairs[2, x4]\), "\[IndentingNewLine]", 
    \(contractedpairs[3, x4]\)}], "Input"],

Cell[BoxData[
    \(contractedpairs[1, x4]\)], "Output"],

Cell[BoxData[
    \(contractedpairs[2, x4]\)], "Output"],

Cell[BoxData[
    \(contractedpairs[3, x4]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(contraction[c[CR, k, \[Alpha], \[Sigma]], 
      c[AN, kp, \[Alpha]p, \[Sigma]p]]\), "\[IndentingNewLine]", 
    \(contraction[c[AN, k, \[Alpha], \[Sigma]], 
        c[CR, kp, \[Alpha]p, \[Sigma]p]] // Simplify\)}], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k  kp\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(\[Alpha]  \[Alpha]p\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Sigma]p\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
        DisplayForm]}]], "Output"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k  kp\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(\[Alpha]  \[Alpha]p\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              TagBox[
                StyleBox[
                  SubscriptBox[
                    TagBox[
                      StyleBox["\<\"\[Delta]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 
                          0.0]]&)], \(\[Sigma]  \[Sigma]p\)],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], " ", 
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[Theta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], "(", \(-kp\), ")"}],
              DisplayForm]}], "+", 
          RowBox[{"vev", "[", 
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 
                        0.0]]&)], \(\[Sigma]  \[Sigma]p\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], "]"}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(contract[{a[AN, \[Sigma]], 
        a[CR, \[Sigma]]}, {{1, 2}}]\), "\[IndentingNewLine]", 
    \(contract[{c[CR, k, \[Alpha], \[Sigma]], 
        c[AN, k, \[Alpha], \[Sigma]]}, {{1, 2}}]\), "\[IndentingNewLine]", 
    \(contract[{c[CR, k1, \[Alpha], \[Sigma]], c[AN, k2, \[Alpha], \[Sigma]], 
        c[CR, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]}, {{1, 2}}]\), "\[IndentingNewLine]", 
    \(contract[{c[CR, k1, \[Alpha], \[Sigma]], c[AN, k2, \[Alpha], \[Sigma]], 
        c[CR, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]}, {{1, 2}, {3, 
          4}}]\), "\[IndentingNewLine]", 
    \(\(\(contract[{c[CR, k1, \[Alpha], \[Sigma]], 
        c[AN, k2, \[Alpha], \[Sigma]], c[CR, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]}, {{1, 4}, {3, 
          2}}]\)\(\[IndentingNewLine]\)
    \) (*\ 
      This\ one\ should\ be\ familiar ... \ *) \), "\[IndentingNewLine]", 
    \(contract[{c[CR, k1, \[Alpha], \[Sigma]], c[CR, k2, \[Alpha], \[Sigma]], 
        c[AN, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]}, {{1, 3}, {2, 
          4}}]\), "\[IndentingNewLine]", 
    \(contract[{c[CR, k1, \[Alpha], \[Sigma]], c[CR, k2, \[Alpha], \[Sigma]], 
        c[AN, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]}, {{1, 4}, {2, 3}}]\)}], "Input"],

Cell[BoxData[
    \(1\)], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[Theta]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
      DisplayForm]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Colon]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k3  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k3, \[Alpha], \[Sigma]}], "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k4, \[Alpha], \[Sigma]}], ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], 
            TagBox[
              StyleBox["\<\"\[Colon]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)]}],
          DisplayForm], ")"}], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm]}]], "Output"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
        DisplayForm]}]], "Output"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
        DisplayForm]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{"-", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k2  k4\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k2\), ")"}],
        DisplayForm]}]], "Output"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k2\), ")"}],
        DisplayForm]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(x1\), "\[IndentingNewLine]", 
    \(wickorder[0, x1]\), "\[IndentingNewLine]", 
    \(wickorder[1, x1]\), "\[IndentingNewLine]", 
    \(wickorder[2, x1] // Simplify\)}], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          
          InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
            Subsuperscript[ c, 
              RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          
          InterpretationBox[\(c\_\(k2  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
            Subsuperscript[ c, 
              RowBox[ {k2, \[Alpha], \[Sigma]}], "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          
          InterpretationBox[\(c\_\(k3  \[Alpha]  \[Sigma]\)\%\(\*"\<\"\"\>"\)\
\),
            Subsuperscript[ c, 
              RowBox[ {k3, \[Alpha], \[Sigma]}], ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          
          InterpretationBox[\(c\_\(k4  \[Alpha]  \[Sigma]\)\%\(\*"\<\"\"\>"\)\
\),
            Subsuperscript[ c, 
              RowBox[ {k4, \[Alpha], \[Sigma]}], ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"\[Colon]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)], 
        RowBox[{
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k2  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k2, \[Alpha], \[Sigma]}], "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k3  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k3, \[Alpha], \[Sigma]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k4, \[Alpha], \[Sigma]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], 
        TagBox[
          StyleBox["\<\"\[Colon]\"\>",
            FontColor->RGBColor[0, 0.392187, 0]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.0, 0.39219300000000001, 0.0]]&)]}],
      DisplayForm]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"-", 
          RowBox[{"(", 
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[Colon]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], 
                RowBox[{
                  TagBox[
                    StyleBox[
                      
                      InterpretationBox[\(c\_\(k2  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                        Subsuperscript[ c, 
                          RowBox[ {k2, \[Alpha], \[Sigma]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      
                      InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                        Subsuperscript[ c, 
                          RowBox[ {k4, \[Alpha], \[Sigma]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], 
                TagBox[
                  StyleBox["\<\"\[Colon]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)]}],
              DisplayForm], ")"}]}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k2  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k2, \[Alpha], \[Sigma]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k3  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k3, \[Alpha], \[Sigma]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k1  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k4, \[Alpha], \[Sigma]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k2\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k1  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k3  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k3, \[Alpha], \[Sigma]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k2\), ")"}],
          DisplayForm]}]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], " ", 
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "-", 
          RowBox[{
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], \(k1  k3\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], " ", 
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], \(k2  k4\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ")"}], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k2\), ")"}],
        DisplayForm]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nc[c[CR, k1, 1, UP], c[CR, k2, 1, UP], c[AN, k1, 1, UP], 
      c[AN, k2, 1, UP]]\), "\[IndentingNewLine]", 
    \(wickorder[2, %] // Simplify\)}], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          InterpretationBox[
            SubsuperscriptBox["c", 
              RowBox[{"k1", "1", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[ c, 
              RowBox[ {k1, 1, 
                StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
              "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          InterpretationBox[
            SubsuperscriptBox["c", 
              RowBox[{"k2", "1", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[ c, 
              RowBox[ {k2, 1, 
                StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
              "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          InterpretationBox[
            SubsuperscriptBox["c", 
              RowBox[{"k1", "1", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)]}], "\<\"\"\>"],
            Subsuperscript[ c, 
              RowBox[ {k1, 1, 
                StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
              ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          InterpretationBox[
            SubsuperscriptBox["c", 
              RowBox[{"k2", "1", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)]}], "\<\"\"\>"],
            Subsuperscript[ c, 
              RowBox[ {k2, 1, 
                StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
              ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        RowBox[{\(-1\), "+", 
          SuperscriptBox[
            TagBox[
              StyleBox[
                SubscriptBox[
                  TagBox[
                    StyleBox["\<\"\[Delta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], "2"]}], ")"}], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k2\), ")"}],
        DisplayForm]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(wick[
      nc[c[AN, k, 1, UP], c[CR, k, 1, UP], c[AN, k1, 1, UP], 
        c[CR, k1, 1, UP]]]\), "\[IndentingNewLine]", 
    \(SimplifyKD[%]\)}], "Input"],

Cell[BoxData[
    RowBox[{"1", "-", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Colon]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k", "1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k, 1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k", "1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k, 1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], 
          TagBox[
            StyleBox["\<\"\[Colon]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)]}],
        DisplayForm], "-", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Colon]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", "1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", "1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], 
          TagBox[
            StyleBox["\<\"\[Colon]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)]}],
        DisplayForm], "-", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Colon]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k", "1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k, 1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", "1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k", "1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k, 1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"k1", "1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {k1, 1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], 
          TagBox[
            StyleBox["\<\"\[Colon]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)]}],
        DisplayForm], "-", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
        DisplayForm], "+", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{"(", 
          RowBox[{
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[Colon]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"k", "1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {k, 1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"k1", "1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {k1, 1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], 
                TagBox[
                  StyleBox["\<\"\[Colon]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)]}],
              DisplayForm], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  SubscriptBox[
                    TagBox[
                      StyleBox["\<\"\[Delta]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], " ", 
              TagBox[
                RowBox[{
                  TagBox[
                    StyleBox["\<\"\[Theta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
                DisplayForm]}]}], ")"}]}], "-", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], "+", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\<\"-\"\>", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Colon]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k", "1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k, 1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k1", "1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k1, 1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k", "1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k, 1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k1", "1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k1, 1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], 
            TagBox[
              StyleBox["\<\"\[Colon]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)]}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm]}], "+", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", "k", ")"}],
        DisplayForm], "-", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", "k", ")"}],
          DisplayForm]}], "-", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], "+", 
      RowBox[{
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", "k1", ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"k1", "1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {k1, 1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k  k1\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", "k1", ")"}],
          DisplayForm]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wick[
      nc[c[CR, k1, \[Alpha], \[Sigma]], c[AN, k2, \[Alpha], \[Sigma]], 
        c[CR, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\<\"-\"\>", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Colon]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k1  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k3  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k3, \[Alpha], \[Sigma]}], "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k2  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k4, \[Alpha], \[Sigma]}], ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], 
            TagBox[
              StyleBox["\<\"\[Colon]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)]}],
          DisplayForm]}], "+", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k3  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k3, \[Alpha], \[Sigma]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k4, \[Alpha], \[Sigma]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k3  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k3, \[Alpha], \[Sigma]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k2  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{"(", 
          RowBox[{
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[Colon]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], 
                RowBox[{
                  TagBox[
                    StyleBox[
                      
                      InterpretationBox[\(c\_\(k1  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                        Subsuperscript[ c, 
                          RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      
                      InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                        Subsuperscript[ c, 
                          RowBox[ {k4, \[Alpha], \[Sigma]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], 
                TagBox[
                  StyleBox["\<\"\[Colon]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)]}],
              DisplayForm], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  SubscriptBox[
                    TagBox[
                      StyleBox["\<\"\[Delta]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], " ", 
              TagBox[
                RowBox[{
                  TagBox[
                    StyleBox["\<\"\[Theta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
                
                DisplayForm]}]}], ")"}]}], "-", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k1  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k4, \[Alpha], \[Sigma]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k1  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k2  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wick[
        nc[c[CR, k1, \[Alpha], \[Sigma]], c[AN, k2, \[Alpha], \[Sigma]], 
          c[CR, k3, \[Alpha], \[Tau]], c[AN, k4, \[Alpha], \[Tau]]]] // 
      Expand\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\<\"-\"\>", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Colon]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], 
            RowBox[{
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k1  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k3  \[Alpha]  \[Tau]\)\%\("\
\[Dagger]"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k3, \[Alpha], \[Tau]}], "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k2  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Tau]\)\%\(\*"\<\"\"\>"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k4, \[Alpha], \[Tau]}], ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], 
            TagBox[
              StyleBox["\<\"\[Colon]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)]}],
          DisplayForm]}], "+", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k1  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Tau]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k4, \[Alpha], \[Tau]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k3  \[Alpha]  \[Tau]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k3, \[Alpha], \[Tau]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Tau]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k4, \[Alpha], \[Tau]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k3  \[Alpha]  \[Tau]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k3, \[Alpha], \[Tau]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k2  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
              
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k1  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k2  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        RowBox[{"(", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              RowBox[{
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k1  \[Alpha]  \[Sigma]\)\%\("\
\[Dagger]"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    
                    InterpretationBox[\(c\_\(k4  \[Alpha]  \
\[Tau]\)\%\(\*"\<\"\"\>"\)\),
                      Subsuperscript[ c, 
                        RowBox[ {k4, \[Alpha], \[Tau]}], ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], 
              TagBox[
                StyleBox["\<\"\[Colon]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], ")"}], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
              
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(y1 = 
      normalorder[
        nc[c[CR, k1, \[Alpha], \[Sigma]], 
          c[AN, k2, \[Alpha], \[Sigma]]]]\), "\[IndentingNewLine]", 
    \(y2 = 
      normalorder[
        nc[c[CR, k3, \[Beta], \[Tau]], 
          c[AN, k4, \[Beta], \[Tau]]]]\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
              Subsuperscript[ c, 
                RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k2  \[Alpha]  \[Sigma]\)\%\(\*"\<\"\"\>"\
\)\),
              Subsuperscript[ c, 
                RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k3  \[Beta]  \[Tau]\)\%\("\[Dagger]"\)\),
              
              Subsuperscript[ c, 
                RowBox[ {k3, \[Beta], \[Tau]}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k4  \[Beta]  \
\[Tau]\)\%\(\*"\<\"\"\>"\)\),
              Subsuperscript[ c, 
                RowBox[ {k4, \[Beta], \[Tau]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(y3 = nc[y1, y2]\), "\[IndentingNewLine]", 
    \(y4 = vevwick[y3]\), "\[IndentingNewLine]", 
    \(SimplifyKD[%]\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(\[Alpha]  \[Beta]\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k4  \[Beta]  \
\[Tau]\)\%\(\*"\<\"\"\>"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k4, \[Beta], \[Tau]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
              Subsuperscript[ c, 
                RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k3  \[Beta]  \[Tau]\)\%\("\[Dagger]"\)\),
              
              Subsuperscript[ c, 
                RowBox[ {k3, \[Beta], \[Tau]}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k2  \[Alpha]  \[Sigma]\)\%\(\*"\<\"\"\>"\
\)\),
              Subsuperscript[ c, 
                RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k4  \[Beta]  \
\[Tau]\)\%\(\*"\<\"\"\>"\)\),
              Subsuperscript[ c, 
                RowBox[ {k4, \[Beta], \[Tau]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k2  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k3  \[Beta]  \
\[Tau]\)\%\("\[Dagger]"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k3, \[Beta], \[Tau]}], "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k4  \[Beta]  \[Tau]\)\%\(\*"\<\"\"\
\>"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k4, \[Beta], \[Tau]}], ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "-", 
            RowBox[{
              TagBox[
                StyleBox[
                  SubscriptBox[
                    TagBox[
                      StyleBox["\<\"\[Delta]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], " ", 
              TagBox[
                RowBox[{
                  TagBox[
                    StyleBox["\<\"\[Theta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
                
                DisplayForm]}]}], ")"}]}]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 
                      0.0]]&)], \(\[Alpha]  \[Beta]\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
              
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 
                      0.0]]&)], \(\[Alpha]  \[Beta]\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
              
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}]}]], "Output"],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(\[Alpha]  \[Beta]\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        StyleBox[
          SubscriptBox[
            TagBox[
              StyleBox["\<\"\[Delta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
        DisplayForm], " ", 
      TagBox[
        RowBox[{
          TagBox[
            StyleBox["\<\"\[Theta]\"\>",
              FontColor->RGBColor[0, 0.392187, 0]],
            (
            StyleForm[ #, FontColor -> RGBColor[ 
              0.0, 0.39219300000000001, 0.0]]&)], "(", "k3", ")"}],
        DisplayForm]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(y5 = Simplify[y3 - y4]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(\[Alpha]  \[Beta]\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k4  \[Beta]  \
\[Tau]\)\%\(\*"\<\"\"\>"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k4, \[Beta], \[Tau]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
              Subsuperscript[ c, 
                RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k3  \[Beta]  \[Tau]\)\%\("\[Dagger]"\)\),
              
              Subsuperscript[ c, 
                RowBox[ {k3, \[Beta], \[Tau]}], "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k2  \[Alpha]  \[Sigma]\)\%\(\*"\<\"\"\>"\
\)\),
              Subsuperscript[ c, 
                RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            
            InterpretationBox[\(c\_\(k4  \[Beta]  \
\[Tau]\)\%\(\*"\<\"\"\>"\)\),
              Subsuperscript[ c, 
                RowBox[ {k4, \[Beta], \[Tau]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 
                      0.0]]&)], \(\[Alpha]  \[Beta]\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
              
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k1  \[Alpha]  \
\[Sigma]\)\%\("\[Dagger]"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k1, \[Alpha], \[Sigma]}], "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              
              InterpretationBox[\(c\_\(k2  \[Alpha]  \
\[Sigma]\)\%\(\*"\<\"\"\>"\)\),
                Subsuperscript[ c, 
                  RowBox[ {k2, \[Alpha], \[Sigma]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 
                      0.0]]&)], \(\[Alpha]  \[Beta]\)],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        SuperscriptBox[
          TagBox[
            StyleBox[
              SubscriptBox[
                TagBox[
                  StyleBox["\<\"\[Delta]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], \(\[Sigma]  \[Tau]\)],
              
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "2"], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k3  \[Beta]  \
\[Tau]\)\%\("\[Dagger]"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k3, \[Beta], \[Tau]}], "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  
                  InterpretationBox[\(c\_\(k4  \[Beta]  \[Tau]\)\%\(\*"\<\"\"\
\>"\)\),
                    Subsuperscript[ c, 
                      RowBox[ {k4, \[Beta], \[Tau]}], ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "-", 
            RowBox[{
              TagBox[
                StyleBox[
                  SubscriptBox[
                    TagBox[
                      StyleBox["\<\"\[Delta]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], " ", 
              TagBox[
                RowBox[{
                  TagBox[
                    StyleBox["\<\"\[Theta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
                
                DisplayForm]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
      y5, {\[Alpha], 1, 2}, {\[Beta], 1, 2}, {\[Sigma], 0, 1}, {\[Tau], 0, 
        1}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k2", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k2, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k2", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k2, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k2", "2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k2, 2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k2", "2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k2, 2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k3", "1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k3, 1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k4", "1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k4, 1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "-", 
            RowBox[{
              TagBox[
                StyleBox[
                  SubscriptBox[
                    TagBox[
                      StyleBox["\<\"\[Delta]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], " ", 
              TagBox[
                RowBox[{
                  TagBox[
                    StyleBox["\<\"\[Theta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
                
                DisplayForm]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k3", "1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k3, 1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k4", "1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k4, 1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "-", 
            RowBox[{
              TagBox[
                StyleBox[
                  SubscriptBox[
                    TagBox[
                      StyleBox["\<\"\[Delta]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], " ", 
              TagBox[
                RowBox[{
                  TagBox[
                    StyleBox["\<\"\[Theta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
                
                DisplayForm]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k3", "2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k3, 2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k4", "2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k4, 2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "-", 
            RowBox[{
              TagBox[
                StyleBox[
                  SubscriptBox[
                    TagBox[
                      StyleBox["\<\"\[Delta]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], " ", 
              TagBox[
                RowBox[{
                  TagBox[
                    StyleBox["\<\"\[Theta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
                
                DisplayForm]}]}], ")"}]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k3", "2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k3, 2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"k4", "2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {k4, 2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "-", 
            RowBox[{
              TagBox[
                StyleBox[
                  SubscriptBox[
                    TagBox[
                      StyleBox["\<\"\[Delta]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], " ", 
              TagBox[
                RowBox[{
                  TagBox[
                    StyleBox["\<\"\[Theta]\"\>",
                      FontColor->RGBColor[0, 0.392187, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
                
                DisplayForm]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[%]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k1", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k1, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k3", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k3, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k2", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k2, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"k4", "2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {k4, 2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k3", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k3, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k3", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k3, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k3", "2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k3, 2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k3", "2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k3, 2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k4", "2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k4, 2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k2", "1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k2, 1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k2", "1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k2, 1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k2", "2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k2, 2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "-", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k1", "2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k1, 2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"k2", "2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {k2, 2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{"4", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k2  k3\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}], "+", 
      RowBox[{"16", " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k1  k2\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          StyleBox[
            SubscriptBox[
              TagBox[
                StyleBox["\<\"\[Delta]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], \(k3  k4\)],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k1\), ")"}],
          DisplayForm], " ", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[Theta]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], "(", \(-k3\), ")"}],
          DisplayForm]}]}]], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{598, 906},
WindowMargins->{{Automatic, 19}, {Automatic, 81}},
Visible->True,
ShowSelection->True,
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Title"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{27, Inherited}, {10, 30}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{27, 10}, {10, 30}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "SlideShow"]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{27, Inherited}, {20, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-.074999999999999997, -.085000000000000006}, {
                0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica",
         "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{27, 10}, {20, 2}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "SlideShow"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{27, Inherited}, {8, 2}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "SlideShow"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{27, Inherited}, {8, 34}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->4,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 2},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "SlideShow"]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{60, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "SlideShow"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{60, Inherited}, {2, 10}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "SlideShow"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{60, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "SlideShow"]],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{60, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "SlideShow"]],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{66, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "SlideShow"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellMargins->{{66, 10}, {7, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["InputOnly", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["InputOnly", "SlideShow"]],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{66, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "SlideShow"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0.6, 0.100008, 0.100008]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "SlideShow"]],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "SlideShow"]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "SlideShow"]],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0.269993, 0.308507, 0.6]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "SlideShow"]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrameLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "SlideShow"]],
  
  Cell[StyleData["FrameLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Inert"],
    StyleMenuListing->None,
    Background->RGBColor[0.870588, 0.905882, 0.972549]],
  
  Cell[StyleData["Inert", "Printout"],
    StyleMenuListing->None,
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "SlideShow"]],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "SlideShow"]],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{60, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "SlideShow"]],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{60, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    CounterAssignments->{{"Outline2", 0}, {"Outline3", 0}, {"Outline4", 0}},
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "SlideShow"]],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{90, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    CounterAssignments->{{"Outline3", 0}, {"Outline4", 0}},
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "SlideShow"]],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{120, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    CounterAssignments->{{"Outline4", 0}},
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "SlideShow"]],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{150, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "SlideShow"]],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "SlideShow"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "SlideShow"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "SlideShow"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "SlideShow"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLinkText", "SlideShow"]],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "SlideShow"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "SlideShow"]],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "SlideShow"]],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "SlideShow"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "SlideShow"]],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, Placeholder]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "SlideShow"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "SlideShow"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display of certain \
types of objects in typeset expressions.  For example, \"UnmatchedBracket\" \
style defines how unmatched bracket, curly bracket, and parenthesis \
characters are displayed (typically by coloring them to make them stand out).\
\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]],
  
  Cell[StyleData["Completions"],
    StyleMenuListing->None,
    FontFamily->"Courier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles from HelpBrowser", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{66, 12}, {2, 24}},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {8, 2}},
    CellFrameColor->GrayLevel[0.700008],
    CellFrameLabelMargins->4,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MathCaption", "SlideShow"]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{39, 0}, {0, 14}},
    Hyphenation->True,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ObjectName", "SlideShow"]],
  
  Cell[StyleData["ObjectName", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Usage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Usage", "SlideShow"]],
  
  Cell[StyleData["Usage", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Notes", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Notes", "SlideShow"]],
  
  Cell[StyleData["Notes", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineOutput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["InlineOutput", "SlideShow"]],
  
  Cell[StyleData["InlineOutput", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Box", "SlideShow"]],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DoubleBox", "SlideShow"]],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["1ColumnBox", "SlideShow"]],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnBox", "SlideShow"]],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenBox", "SlideShow"]],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnSmallBox", "SlideShow"]],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.32}],
  
  Cell[StyleData["3ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnBox", "SlideShow"]],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnSmallBox", "SlideShow"]],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.13, 0.35, 0.13, 0.35}}],
  
  Cell[StyleData["4ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["4ColumnBox", "SlideShow"]],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.202}],
  
  Cell[StyleData["5ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["5ColumnBox", "SlideShow"]],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["6ColumnBox", "SlideShow"]],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FramedBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["FramedBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FramedBox", "SlideShow"]],
  
  Cell[StyleData["FramedBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox3Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox4Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox5Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox6Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopBox", "SlideShow"]],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleBox", "SlideShow"]],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 2}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BottomBox", "SlideShow"]],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopSpanBox", "SlideShow"]],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleSpanBox", "SlideShow"]],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-5, 0}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{27, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Picture", "SlideShow"]],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenCloseItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["OpenCloseItemizedPicture", "SlideShow"]],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedPicture", "SlideShow"]],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListGraphic"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ListGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListGraphic", "SlideShow"]],
  
  Cell[StyleData["ListGraphic", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListNoteBox"],
    CellFrame->0.5,
    CellMargins->{{88, 12}, {8, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ListNoteBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListNoteBox", "SlideShow"]],
  
  Cell[StyleData["ListNoteBox", "Printout"],
    CellMargins->{{77, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{41, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureGroup", "SlideShow"]],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{27, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Sound", "SlideShow"]],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnTable", "SlideShow"]],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenTable", "SlideShow"]],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnTable", "SlideShow"]],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Presentation"]],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{20, 10}, {10, 18}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{14, 10}, {6, 12}},
    FontSize->36],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {8, 8}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {10, 5}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 262, 7, 84, "Text"],

Cell[CellGroupData[{
Cell[2041, 62, 51, 1, 27, "Input"],
Cell[2095, 65, 74, 1, 23, "Print"]
}, Open  ]],
Cell[2184, 69, 193, 4, 50, "Text"],
Cell[2380, 75, 177, 3, 59, "Input"],
Cell[2560, 80, 58, 1, 27, "Input"],
Cell[2621, 83, 382, 7, 75, "Input"],
Cell[3006, 92, 31, 0, 32, "Text"],
Cell[3040, 94, 59, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[3124, 98, 165, 3, 59, "Input"],
Cell[3292, 103, 38, 1, 27, "Output"],
Cell[3333, 106, 38, 1, 27, "Output"]
}, Open  ]],
Cell[3386, 110, 107, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[3518, 117, 69, 1, 27, "Input"],
Cell[3590, 120, 1580, 42, 35, "Output"]
}, Open  ]],
Cell[5185, 165, 51, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[5261, 169, 55, 1, 27, "Input"],
Cell[5319, 172, 1467, 40, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6823, 217, 69, 1, 27, "Input"],
Cell[6895, 220, 1603, 43, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8535, 268, 112, 2, 43, "Input"],
Cell[8650, 272, 6957, 183, 35, "Output"]
}, Open  ]],
Cell[15622, 458, 66, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[15713, 462, 71, 1, 27, "Input"],
Cell[15787, 465, 1200, 34, 38, "Output"]
}, Open  ]],
Cell[17002, 502, 283, 9, 10, "Text"],
Cell[17288, 513, 102, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[17415, 520, 121, 2, 43, "Input"],
Cell[17539, 524, 35, 1, 27, "Output"],
Cell[17577, 527, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17649, 533, 97, 2, 43, "Input"],
Cell[17749, 537, 3186, 84, 35, "Output"],
Cell[20938, 623, 347, 10, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21322, 638, 231, 6, 43, "Input"],
Cell[21556, 646, 304, 9, 27, "Output"],
Cell[21863, 657, 347, 10, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22247, 672, 116, 3, 27, "Input"],
Cell[22366, 677, 749, 22, 31, "Output"]
}, Open  ]],
Cell[23130, 702, 90, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[23245, 708, 154, 3, 43, "Input"],
Cell[23402, 713, 6957, 183, 35, "Output"],
Cell[30362, 898, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30434, 904, 205, 4, 59, "Input"],
Cell[30642, 910, 8339, 221, 60, "Output"],
Cell[38984, 1133, 3291, 93, 33, "Output"],
Cell[42278, 1228, 1579, 43, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43894, 1276, 207, 4, 75, "Input"],
Cell[44104, 1282, 2988, 83, 35, "Output"],
Cell[47095, 1367, 1890, 53, 33, "Output"],
Cell[48988, 1422, 1161, 33, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50186, 1460, 242, 5, 59, "Input"],
Cell[50431, 1467, 4309, 121, 52, "Output"],
Cell[54743, 1590, 3073, 80, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57853, 1675, 176, 4, 59, "Input"],
Cell[58032, 1681, 13278, 350, 85, "Output"],
Cell[71313, 2033, 35, 1, 27, "Output"]
}, Open  ]],
Cell[71363, 2037, 285, 9, 5, "Text"],
Cell[71651, 2048, 40, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[71716, 2052, 233, 5, 43, "Input"],
Cell[71952, 2059, 808, 25, 35, "Output"],
Cell[72763, 2086, 1644, 48, 35, "Output"]
}, Open  ]],
Cell[74422, 2137, 285, 9, 5, "Text"],
Cell[74710, 2148, 50, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[74785, 2152, 119, 2, 27, "Input"],
Cell[74907, 2156, 536, 14, 34, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75480, 2175, 250, 5, 91, "Input"],
Cell[75733, 2182, 38, 1, 27, "Output"],
Cell[75774, 2185, 38, 1, 27, "Output"],
Cell[75815, 2188, 38, 1, 27, "Output"],
Cell[75856, 2191, 35, 1, 27, "Output"],
Cell[75894, 2194, 79, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[76010, 2200, 62, 1, 27, "Input"],
Cell[76075, 2203, 549, 14, 35, "Output"]
}, Open  ]],
Cell[76639, 2220, 283, 9, 10, "Text"],

Cell[CellGroupData[{
Cell[76947, 2233, 189, 4, 27, "Input"],
Cell[77139, 2239, 1656, 51, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78832, 2295, 169, 3, 59, "Input"],
Cell[79004, 2300, 56, 1, 27, "Output"],
Cell[79063, 2303, 56, 1, 27, "Output"],
Cell[79122, 2306, 56, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79215, 2312, 245, 4, 43, "Input"],
Cell[79463, 2318, 1595, 46, 34, "Output"],
Cell[81061, 2366, 2427, 65, 37, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83525, 2436, 1355, 24, 219, "Input"],
Cell[84883, 2462, 35, 1, 27, "Output"],
Cell[84921, 2465, 304, 9, 27, "Output"],
Cell[85228, 2476, 2287, 63, 35, "Output"],
Cell[87518, 2541, 1465, 43, 31, "Output"],
Cell[88986, 2586, 1465, 43, 31, "Output"],
Cell[90454, 2631, 1511, 44, 31, "Output"],
Cell[91968, 2677, 1465, 43, 31, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93470, 2725, 199, 4, 75, "Input"],
Cell[93672, 2731, 1656, 51, 35, "Output"],
Cell[95331, 2784, 2321, 66, 35, "Output"],
Cell[97655, 2852, 9699, 254, 60, "Output"],
Cell[107357, 3108, 2663, 71, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110057, 3184, 177, 3, 59, "Input"],
Cell[110237, 3189, 2988, 83, 35, "Output"],
Cell[113228, 3274, 1217, 34, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[114482, 3313, 176, 4, 59, "Input"],
Cell[114661, 3319, 27238, 679, 158, "Output"],
Cell[141902, 4000, 19736, 494, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161675, 4499, 190, 4, 43, "Input"],
Cell[161868, 4505, 18333, 484, 131, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[180238, 4994, 198, 4, 43, "Input"],
Cell[180439, 5000, 20857, 558, 158, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[201333, 5563, 281, 8, 43, "Input"],
Cell[201617, 5573, 1644, 48, 35, "Output"],
Cell[203264, 5623, 1645, 48, 37, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[204946, 5676, 147, 3, 59, "Input"],
Cell[205096, 5681, 8353, 233, 93, "Output"],
Cell[213452, 5916, 4850, 134, 35, "Output"],
Cell[218305, 6052, 2305, 67, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[220647, 6124, 55, 1, 27, "Input"],
Cell[220705, 6127, 13170, 366, 117, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[233912, 6498, 125, 3, 27, "Input"],
Cell[234040, 6503, 85944, 2258, 435, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[320021, 8766, 44, 1, 27, "Input"],
Cell[320068, 8769, 82832, 2197, 381, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

